package com.javamonkey.test;

/*
 * Copyright (c) 1999 Peter Seibel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

import java.io.PrintStream;

/**
 * An exception thrown to indicate that a test has gone so far wrong
 * that it can't continue to produce meaningful results.
 */
public class TestAbortedException extends RuntimeException {
  
  private Throwable rootCause = null;

  /**
   * Make a TestAbortedException with no message and no root cause.
   */
  public TestAbortedException() {};

  /**
   * Make a TestAbortedException with the give message and no root
   * cause.
   */
  public TestAbortedException(String msg) { super(msg); }

  /**
   * Make a TestAbortedException with no message and the given root
   * cause.
   */
  public TestAbortedException(Throwable root) {
    rootCause = root;
  }

  /**
   * Make a TestAbortedException with the given message and the given
   * root cause.
   */
  public TestAbortedException(String msg, Throwable root) {
    super(msg);
    rootCause = root;
  }

  /**
   * Get the root cause of this exception or null if none.
   */
  public Throwable getRootCause() { return rootCause; }

  public void printStackTrace() {
    printStackTrace(System.err);
  }

  public void printStackTrace(PrintStream ps) {
    super.printStackTrace(ps);
    if (rootCause != null) {
      ps.println("Caused by:");
      rootCause.printStackTrace(ps);
    }
  }

}

