package com.javamonkey.test;

/*
 * Copyright (c) 1999 Peter Seibel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

import java.lang.reflect.*;

/**
 * The base functionality for any program that runs Tests such as the
 * TestConsole or a command line version of same. To wit, given the
 * Class object for a Test: instantiate a new instance of the Test,
 * initialize its properties from an.
 *
 * @version $Id: //depot/macaca/src/com/javamonkey/test/TestRunner.java#2 $
 */
public class TestRunner implements TestListener {

  private int successes = 0;
  private int failures  = 0;
  private int skipped   = 0;
  private int aborted   = 0;

  private Test test;
  
  public TestRunner(Class testClass)
    throws InstantiationException, IllegalAccessException
  {
    test = (Test)testClass.newInstance();
    test.addTestListener(this);
  }

  public TestRunner(String className, ClassLoader loader)
    throws InstantiationException, IllegalAccessException,
	   ClassNotFoundException
  {
    this(loader.loadClass(className));
  }

  public void addTestListener(TestListener listener) {
    test.addTestListener(listener);
  }
  
  public void run() {
    test.run();
  }
  

  // =================================================================
  // TestListener implementation
    
  public void testSucceeded(TestEvent evt) {
    successes++;
  }
  public void testFailed(TestEvent evt) {
    failures++;
  }
  public void testSkipped(TestEvent evt) {
    skipped++;
  }
  public void testAborted(TestEvent evt) {
    aborted++;
  }

  // End TestListener implementation.
  // =================================================================

  public boolean allTestsPassed() {
    return getTotal() == successes;
  }

  public int getTotal() {
    return successes + failures + skipped + aborted;
  }
  
  public int getSuccesses() {
    return successes;
  }

  public int getFailures() {
    return failures;
  }

  public int getSkipped() {
    return skipped;
  }

  public int getAborted() {
    return aborted;
  }

  public double getSuccessPercentage() {
    return (double)successes/getTotal();
  }

  public double getFailurePercentage() {
    return (double)failures/getTotal();
  }

  public double getSkippedPercentage() {
    return (double)skipped/getTotal();
  }

  public double getAbortedPercentage() {
    return (double)aborted/getTotal();
  }
}
