package com.javamonkey.utils.iterators;

/*
 * Copyright (c) 1999 Peter Seibel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

import java.util.*;

/**
 * A degenerate iterator that iterates over a single item.
 *
 * @version $Id$
 */
public class SingleItemIterator implements Iterator {

  
  private final static boolean debug = true;

  private final static Object END = new Object();
  
  private Object item;

  /**
   * Create a SingleItemIterator that will return the given Object on
   * the first call to <code>next()</code>.
   *
   * @param o The object, must not be null.
   */
  public SingleItemIterator(Object o) {
    item = o;
  }

  /**
   * Return true until <code>next()</code> has been called once.
   */
  public boolean hasNext() {
    return item != END;
  }

  /**
   * Return the object passed in in the constructor the first time it
   * is called. After that throws <code>NoSuchElementException</code>.
   */
  public Object next() {
    if (hasNext()) {
      Object tmp = item;
      item = END;
      return tmp;
    } else {
      throw new NoSuchElementException();
    }
  }

  /**
   * Throws UnsupportedOperationException.
   */
  public void remove() {
    throw new UnsupportedOperationException();
  }

}
