package com.javamonkey.utils.parsing;

/*
 * Copyright (c) 1999 Peter Seibel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

import com.javamonkey.test.AutoTest;
import com.javamonkey.utils.AssertionError;
import java.io.StringReader;
import java.io.IOException;

/**
 * Unit test for com.javamonkey.utils.parsing.RecursiveDecentParser. 
 *
 * @version $Id: //depot/macaca/tests/com/javamonkey/utils/parsing/RecursiveDecentParserTest.java#1 $
 */
public class RecursiveDecentParserTest extends AutoTest {

  private final static String INPUT =
    "The quick brown fox jumps over the lazy dog.";

  private RecursiveDecentParser parser;

  public RecursiveDecentParserTest() {
    try {
      parser = new TestParser(INPUT);
    } catch (IOException ioe) {
      throw new AssertionError(ioe);
    }
  }

  public boolean testStartAtStart() {
    return parser.lookingAt('T')
      ? success("Looking at beginning.")
	: failure("Not looking at beginning.");
  }

  public boolean testConsumeOne() {
    require("testStartAtStart");
    parser.start();
    parser.consume();
    return parser.lookingAt('h')
      ? success("ok.")
      : failure("not looking at second character.");
  }

  public boolean testFailBacksUp() {
    require("testConsumeOne");
    parser.failure();
    return parser.lookingAt('T')
      ? success("Back to beginning.")
      : failure("Not looking at beginning.");
  }
  
  public boolean testSuccessMovesForward() {
    require("testFailBacksUp");
    parser.consume();
    parser.consume();
    parser.consume();
    parser.consume();
    if (!parser.lookingAt('q')) {
      return failure("not looking at right thing.");
    }
    parser.success();
    return parser.lookingAt('q')
      ? success("ok.")
      : failure("success() moved us.");
  }
  
  public boolean testLastMatch() {
    require("testSuccessMovesForward");
    String lm = parser.lastMatch();
    return lm.equals("The ")
      ? success("ok.")
      : failure("Got '" + lm + "' not 'The '.");
  }


  private class TestParser extends RecursiveDecentParser {
    TestParser(String s) throws IOException {
      super(new StringReader(s));
    }
  }
}




